/* liststore.c -- parse, store and prepare data for TutoTerm
 *
 * Copyright © 2017 Félicien Pillot <felicien@gnu.org>
 * This file is part of TutoTerm.
 * 
 * TutoTerm is free software: you can redistribute it and/or modify
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * TutoTerm is distributed in the hope that it will be useful,
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * with TutoTerm.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>

#include "../include/gettext.h"
#define _(String) gettext (String)
#include "../include/liststore.h"

GtkListStore*
get_liststore ()
{
  GtkListStore *ttListStore;
  GtkTreeIter iter;
  gchar command[20], descriptionRaw[500], exampleRaw[500],
    *description, *example, filename[200],
    postCommentRaw[1000], *postComment;
  char *line = NULL;
  size_t len = 0;
  ssize_t read, n;
  FILE *descFile;
  ttListStore = gtk_list_store_new (4,
				    G_TYPE_STRING,
				    G_TYPE_STRING,
				    G_TYPE_STRING,
				    G_TYPE_STRING);
  strcpy (filename, ROOT_DIR);
  strcat (filename, "/share/tutoterm/command-descriptions.en.txt");
  descFile = fopen (filename, "r");
  if (descFile == NULL) {
    printf (_("%s: file not found."), filename);
    exit (1);
  }
  while ((read = getline(&line, &len, descFile)) != -1) {
      n = sscanf (line, " %[^;]%*c%[^;]%*c%[^;]%*c%[^\n]",
		  command, descriptionRaw, exampleRaw, postCommentRaw);
      if (n == 4) {
	description = g_strcompress (descriptionRaw); //  Un-escape
	example = g_strcompress (exampleRaw);         //  '\\n' -> '\n'
	postComment = g_strcompress (postCommentRaw); //  to display newlines
	gtk_list_store_append (ttListStore, &iter);
	gtk_list_store_set (ttListStore, &iter, 0, command, 1,
			    description, 2, example, 3, postComment, -1);
	g_free (description);
	g_free (example);
	g_free (postComment);	
      } else {
      	printf (_("Error while parsing %s."), filename);
	exit (1);
      }
    }
  g_free (line);
  fclose (descFile);
  return ttListStore;
}
